@@ -6,8 +6,8 @@ command line interface (cli) code.
 from __future__ import print_function
 import argparse
 from .arguments import Arguments
-import json
-from .pycompat import configparser
+# import json
+# from .pycompat import configparser
 import logging
 import os
 import sys
@@ -21,6 +21,8 @@ def error(*args, **kwargs):  # pragma: nocover
     """
     kwargs['file'] = sys.stderr
     print("\n\tERROR:", *args, **kwargs)
+    if args and args[0].startswith("[Errno 2] No such file or directory"):
+        print("\t(Did you forget to include an __init__.py?)")
     sys.exit(1)
 
 
@@ -44,7 +46,7 @@ def _mkverbose(level):
 
 
 def _find_current_package():
-    startdir = cwd = os.getcwd()
+    cwd = os.getcwd()
     while 'setup.py' not in os.listdir(cwd) and cwd != os.path.dirname(cwd):
         cwd = os.path.dirname(cwd)
     if 'setup.py' not in os.listdir(cwd):
@@ -120,7 +122,7 @@ def parse_args(argv=()):
         args.add('fname', kind="FNAME:input", help='filename')
     else:
         args.add('--fname', kind="FNAME:input", help='filename')
-    
+
     args.add('-v', '--verbose', default=0, action='count', help="be more verbose (-vv, -vvv for more verbosity)")
     args.add('-o', default=None, kind="FNAME:output", dest='output', metavar="file", help="write output to 'file'")
     args.add('-T', default='svg', dest='format', help="output format (svg|png)")
